@@ -29,7 +29,7 @@ impl Application for WidgetWindow {
     }
 
     fn attributes(&self) -> Attributes {
-        Attributes::new(WS_NORMAL, "Widget Window".to_string(),"".to_string(),1280, 750, 100, 100)
+        Attributes::new(WS_NORMAL, "Widget Window".to_string(),"io.github.lattesyobon.widget".to_string(),1280, 750, 100, 100)
     }
 
     fn is_child_window(&self) -> bool {
@@ -66,9 +66,9 @@ fn initialize_menu() -> MenuBar {
     let file_menu = MenuItem::new("File");
     let edit_menu = MenuItem::new("Edit");
     let help_menu = MenuItem::new("Help");
-    menu_bar.add_menu(file_menu);
-    menu_bar.add_menu(edit_menu);
-    menu_bar.add_menu(help_menu);
+    menu_bar.add_menu(file_menu.clone());
+    menu_bar.add_menu(edit_menu.clone());
+    menu_bar.add_menu(help_menu.clone());
 
     // Initialize MenuItem
     // Initialize File Menu
@@ -76,7 +76,7 @@ fn initialize_menu() -> MenuBar {
     let project_item = MenuItem::new("Project");
     let exit_item = MenuItem::new("Exit");
     new_menu.add_menuitem(project_item);
-    file_menu.add_menu(new_menu);
+    file_menu.add_menu(new_menu.clone());
     file_menu.add_separator();
     file_menu.add_menuitem(exit_item);
 
