@@ -1,6 +1,7 @@
 //! Displays an OS-specific message dialog.
 //! Display OS-specific dialogs in Windows environment, and GTK dialogs in Linux environment.
 
+use std::iter::once;
 use crate::window::Frame;
 
 #[cfg(windows)]
@@ -69,8 +70,8 @@ impl<'a> MessageBox<'a> {
 
             let result = MessageBoxW(
                 frame.get_window(),
-                self.message.encode_utf16().collect::<Vec<u16>>().as_mut_ptr(),
-                self.title.encode_utf16().collect::<Vec<u16>>().as_mut_ptr(),
+                self.message.encode_utf16().chain(once(0)).collect::<Vec<u16>>().as_mut_ptr(),
+                self.title.encode_utf16().chain(once(0)).collect::<Vec<u16>>().as_mut_ptr(),
                 self.style | self.button_style,
             );
             info!("The Result of MessageBox is {}",result);
