@@ -1,4 +1,3 @@
-use winapi::um::commctrl::InitCommonControls;
 use crate::io::get_app_dirs;
 use crate::io::storage::Storage;
 use crate::messagebox::MessageBox;
@@ -65,7 +64,7 @@ pub fn create_new_app(application: Box<dyn Application>) {
         let frame = Frame::new(win);
         info!("Frame has been created.");
         info!("UI Phase");
-        application.ui(frame);
+        application.ui(&frame);
 
         let mut message = std::mem::zeroed();
 
@@ -97,26 +96,25 @@ pub fn create_new_app(application: Box<dyn Application>) {
     // Create a window
     use gtk::prelude::*;
 
-    let window = gtk::Window::new(gtk::WindowType::Toplevel);
-    info!("A window has been created. handle: {}",window);
+    let app = gtk::Application::new(Option::from(attributes.app_id.as_str()), Default::default());
+	app.connect_activate(move |app: &gtk::Application| {
+		let window = gtk::ApplicationWindow::new(app);
+		info!("A window has been created. handle: {}",window);
 
-    window.set_title(attributes.title.as_str());
-    window.set_default_size(attributes.width,attributes.height);
-    window.set_window_position(gtk::WindowPosition::Center);
-    window.set_type_hint(advanced_options.get_style());
+		window.set_title(attributes.title.as_str());
+		window.set_default_size(attributes.width,attributes.height);
+		window.set_window_position(gtk::WindowPosition::Center);
+		window.set_type_hint(advanced_options.get_style());
+		
+		let frame = Frame::new(window.clone(),window.application());
+		info!("Frame has been created.");
+		info!("UI Phase");
+		application.ui(&frame);
 
-    window.connect_delete_event(|_, _| {
-        gtk::main_quit();
-        Inhibit(false)
-    });
-    let frame = Frame::new(window.clone());
-    info!("Frame has been created.");
-    info!("UI Phase");
-    application.ui(frame);
+		window.show_all();
+	});
 
-    window.show_all();
-
-    gtk::main();
-    info!("UI Exit");
-    application.exit();
+    app.run();
+    //info!("UI Exit");
+    //application.exit();
 }
\ No newline at end of file
