@@ -37,4 +37,30 @@ impl CheckBox {
             info!("handle: {}",self.handle);
         }
     }
+}
+
+#[cfg(unix)]
+pub struct CheckBox {
+    pub handle: gtk::CheckButton
+}
+
+#[cfg(unix)]
+impl CheckBox {
+    pub fn new(attributes: Attributes,frame: &Frame) -> Self {
+        use gtk::prelude::*;
+        let handle = gtk::CheckButton::with_label(attributes.title.as_str());
+        handle.set_height_request(attributes.height/10);
+        handle.set_width_request(attributes.width/10);
+        handle.set_margin_top(attributes.y);
+        handle.set_margin_start(attributes.x);
+        frame.get_window().add(&handle);
+        Self {
+            handle
+        }
+    }
+
+    pub fn show(&self) {
+        use gtk::prelude::*;
+        self.handle.show();
+    }
 }
\ No newline at end of file
