@@ -5,4 +5,7 @@ pub mod checkbox;
 pub mod radiobutton;
 pub mod label;
 pub mod textedit;
+pub mod menubar;
+pub mod menuitem;
+pub mod menu;
 
