@@ -64,21 +64,20 @@ pub fn create_dialog(dialog: Box<dyn Dialog>) {
     let frame = dialog.frame();
     use gtk::prelude::*;
 
-    let window = gtk::Window::new(gtk::WindowType::Toplevel);
+    let app = gtk::Application::new(Option::from(attributes.app_id.as_str()), Default::default());
+
+    let window = gtk::ApplicationWindow::new(&app);
 
     window.set_title(attributes.title.as_str());
     window.set_default_size(attributes.width,attributes.height);
     window.set_window_position(gtk::WindowPosition::Center);
     window.set_type_hint(gtk::gdk::WindowTypeHint::Utility);
 
-    window.connect_delete_event(|_, _| {
-        gtk::main_quit();
-        Inhibit(false)
-    });
-    let dialog_frame = Frame::new(window.clone());
+    let dialog_frame = Frame::new(window.clone(),window.application());
+
     dialog.ui(dialog_frame);
 
     window.show_all();
 
-    gtk::main();
+    app.run();
 }
\ No newline at end of file
