@@ -1,6 +1,7 @@
 //! Provides traits and tools for displaying windows.
 
 use crate::io::storage::Storage;
+use crate::widget::menubar::MenuBar;
 
 pub mod dialog;
 
@@ -101,6 +102,13 @@ impl Frame {
             SetWindowPos(self.handle, 0, rect.left, rect.top, width, height, 0);
         }
     }
+
+    pub fn set_menu(self,menu: MenuBar) {
+        use windows_sys::Win32::UI::WindowsAndMessaging::SetMenu;
+        unsafe {
+            SetMenu(self.handle,menu.get_menu());
+        }
+    }
 }
 
 #[cfg(windows)]
@@ -116,6 +124,7 @@ impl Default for Frame {
 pub struct Attributes {
     pub style: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_STYLE,
     pub title: String,
+    pub app_id: String,
     pub width: i32,
     pub height: i32,
     pub x: i32,
@@ -124,10 +133,11 @@ pub struct Attributes {
 
 #[cfg(windows)]
 impl Attributes {
-    pub fn new(style: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_STYLE,title: String,width: i32,height: i32,x: i32,y: i32) -> Self {
+    pub fn new(style: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_STYLE,title: String,app_id: String,width: i32,height: i32,x: i32,y: i32) -> Self {
         Self {
             style,
             title,
+            app_id,
             width,
             height,
             x,
@@ -181,7 +191,7 @@ pub trait Application {
     }
 
     /// Writing UI processes and events
-    fn ui(&self,frame: Frame);
+    fn ui(&self,frame: &Frame);
     /// Processing at application termination (optional)
     fn exit(&self) {
     }
@@ -191,23 +201,29 @@ pub trait Application {
 #[derive(Clone)]
 pub struct Frame {
     /// Window body
-    handle: gtk::Window
+    handle: gtk::ApplicationWindow,
+    application: gtk::Application
 }
 
 #[cfg(unix)]
 impl Frame {
     /// Create a new Frame
-    pub fn new(window: gtk::Window) -> Self {
+    pub fn new(window: gtk::ApplicationWindow,application: Option<gtk::Application>) -> Self {
         info!("A window has been created. handle: {}",window);
+		let app = match application {
+			Some(a) => a,
+			None => panic!("Application is None!")
+		};
         Self {
-            handle: window
+            handle: window,
+            application: app
         }
     }
 
     /// Display the window
     pub fn show(&self) {
         use gtk::prelude::*;
-        self.handle.show();
+        self.handle.show_all();
         info!("A window has appeared. handle: {}",self.handle);
     }
 
@@ -240,7 +256,7 @@ impl Frame {
     }
 
     /// Returns the window handle.
-    pub fn get_window(&self) -> gtk::Window {
+    pub fn get_window(&self) -> gtk::ApplicationWindow {
         use std::borrow::Borrow;
         self.handle.borrow().clone()
     }
@@ -256,21 +272,29 @@ impl Frame {
         use gtk::prelude::*;
         self.handle.set_default_size(width,height);
     }
+
+    pub fn set_menu(&self,menu: MenuBar) {
+        use gtk::prelude::*;
+        self.application.set_menubar(Some(&menu.get_menu()));
+    }
 }
 
 #[cfg(unix)]
 impl Default for Frame {
     fn default() -> Self {
         Self {
-            handle: gtk::Window::new(gtk::WindowType::Toplevel)
+            handle: gtk::ApplicationWindow::new(&gtk::Application::new(Some("com.example.demo"),Default::default())),
+            application: gtk::Application::new(Option::from("com.example.demo"),Default::default())
         }
     }
 }
 
 #[cfg(unix)]
+#[derive(Clone)]
 pub struct Attributes {
     pub style: gtk::WindowType,
     pub title: String,
+    pub app_id: String,
     pub width: i32,
     pub height: i32,
     pub x: i32,
@@ -279,10 +303,11 @@ pub struct Attributes {
 
 #[cfg(unix)]
 impl Attributes {
-    pub fn new(style: gtk::WindowType,title: String,width: i32,height: i32,x: i32,y: i32) -> Self {
+    pub fn new(style: gtk::WindowType,title: String,app_id: String,width: i32,height: i32,x: i32,y: i32) -> Self {
         Self {
             style,
             title,
+            app_id,
             width,
             height,
             x,
@@ -292,6 +317,7 @@ impl Attributes {
 }
 
 #[cfg(unix)]
+#[derive(Clone)]
 pub struct AdvancedOptions {
     advanced_style: gtk::gdk::WindowTypeHint
 }
@@ -336,7 +362,7 @@ pub trait Application {
 
     }
     /// Writing UI processes and events
-    fn ui(&self,frame: Frame);
+    fn ui(&self,frame: &Frame);
     /// Processing at application termination (optional)
     fn exit(&self) {
 
